summaryrefslogtreecommitdiff
path: root/src/termhooks.h
diff options
context:
space:
mode:
authorPavel Janík <Pavel@Janik.cz>2002-06-13 14:59:38 +0000
committerPavel Janík <Pavel@Janik.cz>2002-06-13 14:59:38 +0000
commit3b8f9651533611460efda94051a280ad558fac0c (patch)
treeb50078de727f24fa11afa3b45b09a116c8136f1e /src/termhooks.h
parentdf3eebcbcffcf9fd3d96796856e6272cb2bdc01f (diff)
downloademacs-3b8f9651533611460efda94051a280ad558fac0c.tar.gz
Rename enum event_kind items.
Diffstat (limited to 'src/termhooks.h')
-rw-r--r--src/termhooks.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/termhooks.h b/src/termhooks.h
index 6e38747ed2a..63fa1f0ee3b 100644
--- a/src/termhooks.h
+++ b/src/termhooks.h
@@ -201,10 +201,10 @@ extern void (*judge_scroll_bars_hook) P_ ((struct frame *FRAME));
enum event_kind
{
- no_event, /* nothing happened. This should never
+ NO_EVENT, /* nothing happened. This should never
actually appear in the event queue. */
- ascii_keystroke, /* The ASCII code is in .code, perhaps
+ ASCII_KEYSTROKE_EVENT, /* The ASCII code is in .code, perhaps
with modifiers applied.
.modifiers holds the state of the
modifier keys.
@@ -212,13 +212,13 @@ enum event_kind
which the key was typed.
.timestamp gives a timestamp (in
milliseconds) for the keystroke. */
- multibyte_char_keystroke, /* The multibye char code is in .code,
+ MULTIBYTE_CHAR_KEYSTROKE_EVENT, /* The multibyte char code is in .code,
perhaps with modifiers applied.
The others are the same as
- ascii_keystroke. This type of event
+ ASCII_KEYSTROKE_EVENT. This type of event
is generated only when we are using
XIM on X window. */
- non_ascii_keystroke, /* .code is a number identifying the
+ NON_ASCII_KEYSTROKE_EVENT, /* .code is a number identifying the
function key. A code N represents
a key whose name is
function_key_names[N]; function_key_names
@@ -230,8 +230,8 @@ enum event_kind
which the key was typed.
.timestamp gives a timestamp (in
milliseconds) for the keystroke. */
- timer_event, /* A timer fired. */
- mouse_click, /* The button number is in .code; it must
+ TIMER_EVENT, /* A timer fired. */
+ MOUSE_CLICK_EVENT, /* The button number is in .code; it must
be >= 0 and < NUM_MOUSE_BUTTONS, defined
below.
.modifiers holds the state of the
@@ -243,7 +243,7 @@ enum event_kind
.timestamp gives a timestamp (in
milliseconds) for the click. */
#ifdef WINDOWSNT
- mouse_wheel, /* A mouse-wheel event is generated
+ MOUSE_WHEEL_EVENT, /* A mouse-wheel event is generated
on WINDOWSNT by a
wheel on a mouse (e.g., MS Intellimouse).
The event contains a delta that corresponds
@@ -259,12 +259,12 @@ enum event_kind
the wheel event occurred in.
.timestamp gives a timestamp (in
milliseconds) for the wheel event. */
- language_change_event, /* A language_change event is generated
+ LANGUAGE_CHANGE_EVENT, /* A LANGUAGE_CHANGE_EVENT is generated
on WINDOWSNT when the keyboard layout
or input language is changed by the
user. */
#endif
- scroll_bar_click, /* .code gives the number of the mouse button
+ SCROLL_BAR_CLICK_EVENT, /* .code gives the number of the mouse button
that was clicked.
.modifiers holds the state of the modifier
keys.
@@ -278,23 +278,23 @@ enum event_kind
.timestamp gives a timestamp (in
milliseconds) for the click. */
#ifdef WINDOWSNT
- w32_scroll_bar_click, /* as for scroll_bar_click, but only generated
+ W32_SCROLL_BAR_CLICK_EVENT, /* as for SCROLL_BAR_CLICK, but only generated
by MS-Windows scroll bar controls. */
#endif
- selection_request_event, /* Another X client wants a selection from us.
+ SELECTION_REQUEST_EVENT, /* Another X client wants a selection from us.
See `struct selection_event'. */
- selection_clear_event, /* Another X client cleared our selection. */
- buffer_switch_event, /* A process filter has switched buffers. */
- delete_window_event, /* An X client said "delete this window". */
+ SELECTION_CLEAR_EVENT, /* Another X client cleared our selection. */
+ BUFFER_SWITCH_EVENT, /* A process filter has switched buffers. */
+ DELETE_WINDOW_EVENT, /* An X client said "delete this window". */
MENU_BAR_EVENT, /* An event generated by the menu bar.
The frame_or_window field's cdr holds the
Lisp-level event value.
(Only the toolkit version uses these.) */
- iconify_event, /* An X client iconified this window. */
- deiconify_event, /* An X client deiconified this window. */
- menu_bar_activate_event, /* A button press in the menu bar
+ ICONIFY_EVENT, /* An X client iconified this window. */
+ DEICONIFY_EVENT, /* An X client deiconified this window. */
+ MENU_BAR_ACTIVATE_EVENT, /* A button press in the menu bar
(toolkit version only). */
- drag_n_drop, /* A drag-n-drop event is generated when
+ DRAG_N_DROP_EVENT, /* A drag-n-drop event is generated when
files selected outside of Emacs are dropped
onto an Emacs window.
Currently used only on Windows NT.
@@ -330,11 +330,11 @@ enum event_kind
/* Queued from XTread_socket when session manager sends
save yourself before shutdown. */
- save_session_event
+ SAVE_SESSION_EVENT
};
-/* If a struct input_event has a kind which is selection_request_event
- or selection_clear_event, then its contents are really described
+/* If a struct input_event has a kind which is SELECTION_REQUEST_EVENT
+ or SELECTION_CLEAR_EVENT, then its contents are really described
by `struct selection_event'; see xterm.h. */
/* The keyboard input buffer is an array of these structures. Each one
@@ -347,9 +347,9 @@ struct input_event
/* What kind of event was this? */
enum event_kind kind;
- /* For an ascii_keystroke and multibyte_char_keystroke, this is the
- character.
- For a non_ascii_keystroke, this is the keysym code.
+ /* For an ASCII_KEYSTROKE_EVENT and MULTIBYTE_CHAR_KEYSTROKE_EVENT,
+ this is the character.
+ For a NON_ASCII_KEYSTROKE_EVENT, this is the keysym code.
For a mouse event, this is the button number. */
/* In WindowsNT, for a mouse wheel event, this is the delta. */
int code;